===========
kishimen.py
===========

The niconico Downloader.

Requirements
============

- Python 3.3
- requests

Installation
============

::

   $ cd <directory containing this file>
   $ python setup.py develop

Usage
=====

::

   $ kishimenpy download -m <your niconico account's mail address> -p <your password> -d <destination directory> <nicovideo url>...
